function contact_vec = determine_contacts(index, people_data, gqpeople_data, gq_data, params)

% Computes the network contacts of an agent and assigns weights to those
% contacts.
% Inputs: index - index of the current agent, integer between 1 and nr_agents
%         people_data and gqpeople_data - data structures from readdata.m
%         nr_agents - total number of agents in the simulation
%         min_nr_contacts and max_nr_contacts - smallest and largest numbers
%           (respectively) of regular contacts that an agent would have in 
%           a large workplace or school
%         weights - structure with fields hh, wp, sch, and gq that contain
%           the contact weights corresponding to households, workplaces,
%           schools, and group quarters, respectively.
% Output: contact_vec is a vector of length nr_agents such that
%           contact_vec(i) is the contact weight between the current agent 
%           and agent i.

 
    nr_agents = length(people_data.sp_id)+length(gqpeople_data.sp_id);

    if index <= length(people_data.sp_id)
        Ihh = find(people_data.sp_hh_id == people_data.sp_hh_id(index));
        Iwp = find(people_data.sp_work_id == people_data.sp_work_id(index));
        Isch = find(people_data.sp_school_id == people_data.sp_school_id(index));
        Igq = [];
        nr_cas_contacts = randi([params.min_cas_contacts,params.max_cas_contacts],1);
        Icas = randperm(nr_agents,nr_cas_contacts);
    else
        Ihh = [];
        Iwp = [];
        Isch = [];
        Igq = length(people_data.sp_id) + find(gqpeople_data.sp_gq_id == gqpeople_data.sp_gq_id(index-length(people_data.sp_id)));
        gqtype = cell2mat(gq_data.gq_type(gq_data.sp_id==gqpeople_data.sp_gq_id(index-length(people_data.sp_id))));
        if strcmp(gqtype,'P')
            Icas = [];
        else
            nr_cas_contacts = randi([params.min_cas_contacts,params.max_cas_contacts],1);
            Icas = randperm(nr_agents,nr_cas_contacts);
        end
    end

    if length(Iwp) > params.min_nr_contacts
        nr_wp_contacts = randi([params.min_nr_contacts min(length(Iwp),params.max_nr_contacts)],1);
        Iwp = Iwp(randperm(length(Iwp),nr_wp_contacts));
    end
    if length(Isch) > params.min_nr_contacts
        nr_sch_contacts = randi([params.min_nr_contacts min(length(Isch),params.max_nr_contacts)],1);
        Isch = Isch(randperm(length(Isch),nr_sch_contacts));
    end
    if length(Igq) > params.min_nr_contacts
        nr_gq_contacts = randi([params.min_nr_contacts min(length(Igq),params.max_nr_contacts)],1);
        Igq = Igq(randperm(length(Igq),nr_gq_contacts));
    end

    % Assign contact weights
    contact_vec = sparse(nr_agents,1);
    contact_vec(Ihh) = params.weights.hh;
    contact_vec(Iwp) = params.weights.wp;
    contact_vec(Isch) = params.weights.sch;
    contact_vec(Igq) = params.weights.gq;
    contact_vec(Icas) = params.weights.cas;
    
end