function main_nonspatial_SEI(settingsfile, seedfile)

% Simulates contacts based on households, workplaces, schools, and group 
% quarters. Model is not spatially explicit in that there is no movement of 
% agents, but rather is network structured.
%
% Agents are placed in households, workplaces, and schools according to the 
% synthetic population data from Wheaton et al. (2009). Some agents can 
% start as "infected" and can infect others based on the contact rates
% between them.
% Spatial coordinates are in [longitude latitude] (but these are not used 
% for simulation purposes).
% Time is in days.
%
% Uses the following m-files:
%   agent.m - to define agent objects
% 	readdata.m - to read in synthetic population data
%   storedata_network.m - to write model data to file in each time step
%   initialize_agents.m - initializes agent attributes and disease states
%   advance_in_time.m - performs a single time step of the simulation
%
% Inputs: settingsfile - the name of the .m file (don't include the '.m') 
%           or function handle that defines the parameter values for the 
%           current run
%         seedfile (optional) - the name of the .mat file containing the
%           random seed information

params = feval(settingsfile);
if nargin==2
    load(seedfile,'SeedInfoList')
    rng(SeedInfoList)
end

if ~isempty(params.savedir)
    mkdir(params.savedir)
    savedir = [params.savedir,'/'];
else
    savedir = '';
end
savefile = [params.savedir,'/params.mat'];
save(savefile,'params')

nr_timesteps = round(params.nr_days/params.dt);


%% Read in synthetic population data
[people_data,household_data,workplace_data,school_data,gq_data,gqpeople_data] = readdata(params.countyfolder);
gq_types = gq_data.gq_type; % group quarter types. Can be N (nursing), C (college), P (prison), M (military)
age_vec = [people_data.age; gqpeople_data.age];
nr_agents = length(people_data.sp_id)+length(gqpeople_data.sp_id);

% Matlab has decided that people_data.sp_work_id is a cell array of
% character strings rather than an array of numbers, so this chunk is to
% change it back to a numeric array.
for i = 1:length(people_data.sp_work_id)
    if isempty(cell2mat(people_data.sp_work_id(i)))
        people_data.sp_work_id(i) = {'NaN      '};
    end
end
people_data.sp_work_id = str2num(cell2mat(people_data.sp_work_id));

infected_matrix = zeros(nr_timesteps,params.nr_reps);
incidence_matrix = zeros(nr_timesteps,params.nr_reps);
latent_matrix = zeros(nr_timesteps,params.nr_reps);
nr_latent = round(params.fraction_latent*nr_agents);


for run_number = 1:params.nr_reps
    % Store random number info
    if params.savedata
        MatlabVersion=version;
        DateAndTimeList=datetime;
        SeedInfoList=rng;
        seedfile_cur = [savedir,params.seedfile,num2str(run_number)];
        save(seedfile_cur,'MatlabVersion','DateAndTimeList','SeedInfoList')
    end
    
    % Define initial conditions
    [agents, infected_init, latent_init] = initialize_agents(nr_agents, nr_latent, age_vec, ...
    params, people_data, household_data, workplace_data, school_data, gq_data, gqpeople_data);
    
    infected = infected_init;
    exposed = [];
    exposed_secondary = [];
    latent = latent_init;
    time = params.time_init;
    
    % Store initial model data
    if params.savestates
        savefile_cur = [savedir,params.savefile,num2str(run_number)];
        fid = fopen(savefile_cur,'w');
        infectedby = zeros(length(infected),2);
        for i = 1:length(infected)
            infectedby(i,:) = agents(infected(i)).infected_by;
        end
        storedata_network(fid, time, infected, infectedby, exposed, latent);
    end
        
    
    tic
    %% Advance in time
    for timestep = 1:nr_timesteps
        
        infected_old = infected;
        [agents, time, exposed, latent, exposed_secondary, infected] = advance_in_time(agents, time, ...
            exposed, exposed_secondary, latent, infected, people_data, gqpeople_data, gq_data, params);
        new_infections = setdiff(infected, infected_old);
        
        % Save model data to file
        if params.savestates
            infectedby = zeros(length(infected),2);
            for i = 1:length(infected)
                infectedby(i,:) = agents(infected(i)).infected_by;
            end
            storedata_network(fid, time, infected, infectedby,exposed, latent);
        end
        infected_matrix(timestep,run_number) = length(infected);
        incidence_matrix(timestep,run_number) = length(new_infections);
        latent_matrix(timestep,run_number) = length(latent)+length(exposed_secondary);
    end

end

if params.savedata
    save([savedir,'matrixdata.mat'],'infected_matrix','latent_matrix','incidence_matrix')
end

plot_output;

end