function [agents, exposed, latent, infected] = progress_from_exposed(agents, exposed, latent, infected, people_data, gqpeople_data, gq_data, params)

% Determines for each agent in the Exposed compartment whether they will
% progress to Latent, Infected, or back to Susceptible this time step, and
% updates their status.
%
% Calls determine_contacts.m
%
% Input: agents - vector of agent objects
%        exposed, latent, and infected - vectors containing the indices of 
%           all agents in the Exposed, Latent, and Infected compartments,
%           respectively.
%        other inputs are for use in determine_contacts.m:
%           people_data, gqpeople_data - data structures from readdata.m
%           min_nr_contacts, max_nr_contacts - min/max number of contacts 
%               for agents in large schools and workplaces
%           weights - structure with fields hh, wp, sch, and gq containing
%               contact weights corresponding to households, workplaces,
%               schools, and group quarters.
% Output: agents - vector of agents with updated status.
%         exposed, latent, infected - updated vectors of indices of agents
%           in the Exposed, Latent, and Infected compartments.

    agents_leaving_exposed = [];
    for exposed_index = 1:length(exposed)
        ind = exposed(exposed_index);
        
        if ~strcmp(agents(ind).status,'E')
            error('Disagreement between agent statuses and exposed index vector')
        end
        
        rtemp = rand;
        
        prob_to_S = agents(ind).progression_from_exposure*(1-agents(ind).primary_prob)*(1-agents(ind).susceptibility);
        prob_to_I = agents(ind).progression_from_exposure*agents(ind).primary_prob;
        prob_to_L = agents(ind).progression_from_exposure*(1-agents(ind).primary_prob)*agents(ind).susceptibility;

        % Progress to primary infection
        if rtemp < prob_to_I
            agents(ind).status = 'I';

            % Determine network contacts
            if isempty(agents(ind).contact_vec)
                agents(ind).contact_vec = determine_contacts(ind, people_data, gqpeople_data, gq_data, params);
            end
            
            % Updated vector of infected agent indices
            infected = [infected ind];
            agents_leaving_exposed = [agents_leaving_exposed exposed_index];

        % Progress to latent infection
        elseif rtemp < prob_to_I+prob_to_L
            agents(ind).status = 'L';
            
            % Update vector of latent agent indices
            latent = [latent ind];
            agents_leaving_exposed = [agents_leaving_exposed exposed_index];

        % Clear first infection and return to Susceptible
        elseif rtemp < prob_to_I+prob_to_L+prob_to_S
            agents(ind).status = 'S';
            
            agents_leaving_exposed = [agents_leaving_exposed exposed_index];
        end
    end
    exposed(agents_leaving_exposed) = [];

end