function [agents, latent, exposed_secondary, infected] = progress_from_secondary_exposure(agents, latent, exposed_secondary, infected, people_data, gqpeople_data, gq_data, params)

% Determines for each agent in the Es compartment (latent with secondary 
% exposure) whether they will progress to Infected through reinfection.
%
% Calls determine_contacts.m
%
% Input: agents - vector of agent objects
%        latent and infected - vectors containing the indices of all agents 
%           in the Latent, and Infected compartments, respectively.
%        other inputs are for use in determine_contacts.m:
%           people_data, gqpeople_data - data structures from readdata.m
%           params - model parameters defined in define_params.m.
% Output: agents - vector of agents with updated status.
%         latent and infected - updated vectors of indices of agents in the 
%         Latent, and Infected compartments.

    agents_leaving_exposed = [];
    for exposed_index = 1:length(exposed_secondary)
        ind = exposed_secondary(exposed_index);
        
        if ~strcmp(agents(ind).status,'Es')
            error('Disagreement between agent statuses and secondary exposure index vector')
        end

        % Determine if agent will develop reinfection
        rtemp = rand;
        
        prob_to_I = (1-agents(ind).protection_from_reinfection)*agents(ind).progression_from_exposure*agents(ind).primary_prob;
        prob_to_L = agents(ind).progression_from_exposure*(1-(1-agents(ind).protection_from_reinfection)*agents(ind).primary_prob);

        % Progress to primary infection
        if rtemp < prob_to_I
            agents(ind).status = 'I';

            % Determine network contacts
            if isempty(agents(ind).contact_vec)
                agents(ind).contact_vec = determine_contacts(ind, people_data, gqpeople_data, gq_data, params);
            end
            
            % Updated vector of infected agent indices
            infected = [infected ind];
            agents_leaving_exposed = [agents_leaving_exposed exposed_index];

        % Progress to latent infection
        elseif rtemp < prob_to_I+prob_to_L
            agents(ind).status = 'L';
            
            % Update vector of latent agent indices
            latent = [latent ind];
            agents_leaving_exposed = [agents_leaving_exposed exposed_index];
        end
    end
    exposed_secondary(agents_leaving_exposed) = [];

end
